==> dotnet8_8.0.104-8.0.4.orig.tar.xz: src/source-build-reference-packages/src/referencePackages/src/microsoft.visualbasic/10.3.0/ref/netstandard2.0/Microsoft.VisualBasic.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.
// ------------------------------------------------------------------------------
// Changes to this file must follow the http://aka.ms/api-review process.
// ------------------------------------------------------------------------------
[assembly: System.Runtime.CompilerServices.CompilationRelaxations(8)]
[assembly: System.Runtime.CompilerServices.RuntimeCompatibility(WrapNonExceptionThrows = true)]
[assembly: System.Diagnostics.Debuggable(System.Diagnostics.DebuggableAttribute.DebuggingModes.IgnoreSymbolStoreSequencePoints)]
[assembly: System.Security.AllowPartiallyTrustedCallers]
[assembly: System.Runtime.CompilerServices.ReferenceAssembly]
[assembly: System.Reflection.AssemblyTitle("Microsoft.VisualBasic")]
[assembly: System.Reflection.AssemblyDescription("Microsoft.VisualBasic")]
[assembly: System.Reflection.AssemblyDefaultAlias("Microsoft.VisualBasic")]
[assembly: System.Reflection.AssemblyCompany("Microsoft Corporation")]
[assembly: System.Reflection.AssemblyProduct("Microsoft® .NET Framework")]
[assembly: System.Reflection.AssemblyCopyright("© Microsoft Corporation.  All rights reserved.")]
[assembly: System.Reflection.AssemblyFileVersion("4.6.26515.06")]
[assembly: System.Reflection.AssemblyInformationalVersion("4.6.26515.06 @BuiltBy: dlab-DDVSOWINAGE059 @Branch: release/2.1 @SrcCode: https://github.com/dotnet/corefx/tree/30ab651fcb4354552bd4891619a0bdd81e0ebdbf")]
[assembly: System.CLSCompliant(true)]
[assembly: System.Reflection.AssemblyMetadata(".NETFrameworkAssembly", "")]
[assembly: System.Reflection.AssemblyMetadata("Serviceable", "True")]
[assembly: System.Reflection.AssemblyMetadata("PreferInbox", "True")]
[assembly: System.Reflection.AssemblyVersionAttribute("10.0.0.0")]
[assembly: System.Reflection.AssemblyFlagsAttribute((System.Reflection.AssemblyNameFlags)0x70)]
namespace Microsoft.VisualBasic
{
    public enum CallType
    {
        Method = 1,
        Get = 2,
        Let = 4,
        Set = 8
    }

    [CompilerServices.StandardModule]
    public sealed partial class Constants
    {
        internal Constants() { }

        public const string vbBack = "\b";
        public const string vbCr = "\r";
        public const string vbCrLf = "\r\n";
        public const string vbFormFeed = "\f";
        public const string vbLf = "\n";
        [System.Obsolete("For a carriage return and line feed, use vbCrLf.  For the current platform's newline, use System.Environment.NewLine.")]
        public const string vbNewLine = "\r\n";
        public const string vbNullChar = "\0";
        public const string vbNullString = null;
        public const string vbTab = "\t";
        public const string vbVerticalTab = "\v";
    }

    [System.AttributeUsage(System.AttributeTargets.Class, AllowMultiple = false, Inherited = false)]
    public sealed partial class HideModuleNameAttribute : System.Attribute
    {
    }

    [CompilerServices.StandardModule]
    public sealed partial class Strings
    {
        internal Strings() { }

        public static int AscW(char String) { throw null; }

        public static int AscW(string String) { throw null; }

        public static char ChrW(int CharCode) { throw null; }
    }
}

namespace Microsoft.VisualBasic.CompilerServices
{
    public sealed partial class Conversions
    {
        internal Conversions() { }

        public static object ChangeType(object Expression, System.Type TargetType) { throw null; }

        public static bool ToBoolean(object Value) { throw null; }

        public static bool ToBoolean(string Value) { throw null; }

        public static byte ToByte(object Value) { throw null; }

        public static byte ToByte(string Value) { throw null; }

        public static char ToChar(object Value) { throw null; }

        public static char ToChar(string Value) { throw null; }

        public static char[] ToCharArrayRankOne(object Value) { throw null; }

        public static char[] ToCharArrayRankOne(string Value) { throw null; }

        public static System.DateTime ToDate(object Value) { throw null; }

        public static System.DateTime ToDate(string Value) { throw null; }

        public static decimal ToDecimal(bool Value) { throw null; }

        public static decimal ToDecimal(object Value) { throw null; }

        public static decimal ToDecimal(string Value) { throw null; }

        public static double ToDouble(object Value) { throw null; }

        public static double ToDouble(string Value) { throw null; }

        public static T ToGenericParameter<T>(object Value) { throw null; }

        public static int ToInteger(object Value) { throw null; }

        public static int ToInteger(string Value) { throw null; }

        public static long ToLong(object Value) { throw null; }

        public static long ToLong(string Value) { throw null; }

        [System.CLSCompliant(false)]
        public static sbyte ToSByte(object Value) { throw null; }

        [System.CLSCompliant(false)]
        public static sbyte ToSByte(string Value) { throw null; }

        public static short ToShort(object Value) { throw null; }

        public static short ToShort(string Value) { throw null; }

        public static float ToSingle(object Value) { throw null; }

        public static float ToSingle(string Value) { throw null; }

        public static string ToString(bool Value) { throw null; }

        public static string ToString(byte Value) { throw null; }

        public static string ToString(char Value) { throw null; }

        public static string ToString(System.DateTime Value) { throw null; }

        public static string ToString(decimal Value) { throw null; }

        public static string ToString(double Value) { throw null; }

        public static string ToString(short Value) { throw null; }

        public static string ToString(int Value) { throw null; }

        public static string ToString(long Value) { throw null; }

        public static string ToString(object Value) { throw null; }

        public static string ToString(float Value) { throw null; }

        [System.CLSCompliant(false)]
        public static string ToString(uint Value) { throw null; }

        [System.CLSCompliant(false)]
        public static string ToString(ulong Value) { throw null; }

        [System.CLSCompliant(false)]
        public static uint ToUInteger(object Value) { throw null; }

        [System.CLSCompliant(false)]
        public static uint ToUInteger(string Value) { throw null; }

        [System.CLSCompliant(false)]
        public static ulong ToULong(object Value) { throw null; }

        [System.CLSCompliant(false)]
        public static ulong ToULong(string Value) { throw null; }

        [System.CLSCompliant(false)]
        public static ushort ToUShort(object Value) { throw null; }

        [System.CLSCompliant(false)]
        public static ushort ToUShort(string Value) { throw null; }
    }

    [System.AttributeUsage(System.AttributeTargets.Class, AllowMultiple = false, Inherited = false)]
    public sealed partial class DesignerGeneratedAttribute : System.Attribute
    {
    }

    public sealed partial class IncompleteInitialization : System.Exception
    {
    }

    public sealed partial class NewLateBinding
    {
        internal NewLateBinding() { }

        public static object LateCall(object Instance, System.Type Type, string MemberName, object[] Arguments, string[] ArgumentNames, System.Type[] TypeArguments, bool[] CopyBack, bool IgnoreReturn) { throw null; }

        public static object LateGet(object Instance, System.Type Type, string MemberName, object[] Arguments, string[] ArgumentNames, System.Type[] TypeArguments, bool[] CopyBack) { throw null; }

        public static object LateIndexGet(object Instance, object[] Arguments, string[] ArgumentNames) { throw null; }

        public static void LateIndexSet(object Instance, object[] Arguments, string[] ArgumentNames) { }

        public static void LateIndexSetComplex(object Instance, object[] Arguments, string[] ArgumentNames, bool OptimisticSet, bool RValueBase) { }

        public static void LateSet(object Instance, System.Type Type, string MemberName, object[] Arguments, string[] ArgumentNames, System.Type[] TypeArguments, bool OptimisticSet, bool RValueBase, CallType CallType) { }

        public static void LateSet(object Instance, System.Type Type, string MemberName, object[] Arguments, string[] ArgumentNames, System.Type[] TypeArguments) { }

        public static void LateSetComplex(object Instance, System.Type Type, string MemberName, object[] Arguments, string[] ArgumentNames, System.Type[] TypeArguments, bool OptimisticSet, bool RValueBase) { }
    }

    public sealed partial class ObjectFlowControl
    {
        internal ObjectFlowControl() { }

        public static void CheckForSyncLockOnValueType(object Expression) { }

        public sealed partial class ForLoopControl
        {
            internal ForLoopControl() { }

            public static bool ForLoopInitObj(object Counter, object Start, object Limit, object StepValue, ref object LoopForResult, ref object CounterResult) { throw null; }

            public static bool ForNextCheckDec(decimal count, decimal limit, decimal StepValue) { throw null; }

            public static bool ForNextCheckObj(object Counter, object LoopObj, ref object CounterResult) { throw null; }

            public static bool ForNextCheckR4(float count, float limit, float StepValue) { throw null; }

            public static bool ForNextCheckR8(double count, double limit, double StepValue) { throw null; }
        }
    }

    public sealed partial class Operators
    {
        internal Operators() { }

        public static object AddObject(object Left, object Right) { throw null; }

        public static object AndObject(object Left, object Right) { throw null; }

        public static object CompareObjectEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static object CompareObjectGreater(object Left, object Right, bool TextCompare) { throw null; }

        public static object CompareObjectGreaterEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static object CompareObjectLess(object Left, object Right, bool TextCompare) { throw null; }

        public static object CompareObjectLessEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static object CompareObjectNotEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static int CompareString(string Left, string Right, bool TextCompare) { throw null; }

        public static object ConcatenateObject(object Left, object Right) { throw null; }

        public static bool ConditionalCompareObjectEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static bool ConditionalCompareObjectGreater(object Left, object Right, bool TextCompare) { throw null; }

        public static bool ConditionalCompareObjectGreaterEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static bool ConditionalCompareObjectLess(object Left, object Right, bool TextCompare) { throw null; }

        public static bool ConditionalCompareObjectLessEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static bool ConditionalCompareObjectNotEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static object DivideObject(object Left, object Right) { throw null; }

        public static object ExponentObject(object Left, object Right) { throw null; }

        public static object IntDivideObject(object Left, object Right) { throw null; }

        public static object LeftShiftObject(object Operand, object Amount) { throw null; }

        public static object ModObject(object Left, object Right) { throw null; }

        public static object MultiplyObject(object Left, object Right) { throw null; }

        public static object NegateObject(object Operand) { throw null; }

        public static object NotObject(object Operand) { throw null; }

        public static object OrObject(object Left, object Right) { throw null; }

        public static object PlusObject(object Operand) { throw null; }

        public static object RightShiftObject(object Operand, object Amount) { throw null; }

        public static object SubtractObject(object Left, object Right) { throw null; }

        public static object XorObject(object Left, object Right) { throw null; }
    }

    [System.AttributeUsage(System.AttributeTargets.Parameter, Inherited = false, AllowMultiple = false)]
    public sealed partial class OptionCompareAttribute : System.Attribute
    {
    }

    [System.AttributeUsage(System.AttributeTargets.Class, Inherited = false, AllowMultiple = false)]
    public sealed partial class OptionTextAttribute : System.Attribute
    {
    }

    public sealed partial class ProjectData
    {
        internal ProjectData() { }

        public static void ClearProjectError() { }

        public static void SetProjectError(System.Exception ex, int lErl) { }

        public static void SetProjectError(System.Exception ex) { }
    }

    [System.AttributeUsage(System.AttributeTargets.Class, Inherited = false, AllowMultiple = false)]
    public sealed partial class StandardModuleAttribute : System.Attribute
    {
    }

    public sealed partial class StaticLocalInitFlag
    {
        public short State;
    }

    public sealed partial class Utils
    {
        internal Utils() { }

        public static System.Array CopyArray(System.Array arySrc, System.Array aryDest) { throw null; }
    }
}

==> dotnet8_8.0.115-8.0.15.orig.tar.xz: src/source-build-reference-packages/src/referencePackages/src/microsoft.visualbasic/10.3.0/ref/netstandard1.1/Microsoft.VisualBasic.cs <==
// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.
// ------------------------------------------------------------------------------
// Changes to this file must follow the http://aka.ms/api-review process.
// ------------------------------------------------------------------------------
[assembly: System.Runtime.CompilerServices.CompilationRelaxations(8)]
[assembly: System.Runtime.CompilerServices.RuntimeCompatibility(WrapNonExceptionThrows = true)]
[assembly: System.Diagnostics.Debuggable(System.Diagnostics.DebuggableAttribute.DebuggingModes.IgnoreSymbolStoreSequencePoints)]
[assembly: System.Security.AllowPartiallyTrustedCallers]
[assembly: System.Runtime.CompilerServices.ReferenceAssembly]
[assembly: System.Reflection.AssemblyTitle("Microsoft.VisualBasic")]
[assembly: System.Reflection.AssemblyDescription("Microsoft.VisualBasic")]
[assembly: System.Reflection.AssemblyDefaultAlias("Microsoft.VisualBasic")]
[assembly: System.Reflection.AssemblyCompany("Microsoft Corporation")]
[assembly: System.Reflection.AssemblyProduct("Microsoft® .NET Framework")]
[assembly: System.Reflection.AssemblyCopyright("© Microsoft Corporation.  All rights reserved.")]
[assembly: System.Reflection.AssemblyFileVersion("1.0.24212.01")]
[assembly: System.Reflection.AssemblyInformationalVersion("1.0.24212.01. Commit Hash: 9688ddbb62c04189cac4c4a06e31e93377dccd41")]
[assembly: System.CLSCompliant(true)]
[assembly: System.Reflection.AssemblyMetadata(".NETFrameworkAssembly", "")]
[assembly: System.Reflection.AssemblyMetadata("Serviceable", "True")]
[assembly: System.Reflection.AssemblyVersionAttribute("10.0.0.0")]
[assembly: System.Reflection.AssemblyFlagsAttribute((System.Reflection.AssemblyNameFlags)0x70)]
namespace Microsoft.VisualBasic
{
    public enum CallType
    {
        Method = 1,
        Get = 2,
        Let = 4,
        Set = 8
    }

    [CompilerServices.StandardModule]
    public sealed partial class Constants
    {
        internal Constants() { }

        public const string vbBack = "\b";
        public const string vbCr = "\r";
        public const string vbCrLf = "\r\n";
        public const string vbFormFeed = "\f";
        public const string vbLf = "\n";
        [System.Obsolete("For a carriage return and line feed, use vbCrLf.  For the current platform's newline, use System.Environment.NewLine.")]
        public const string vbNewLine = "\r\n";
        public const string vbNullChar = "\0";
        public const string vbNullString = null;
        public const string vbTab = "\t";
        public const string vbVerticalTab = "\v";
    }

    [System.AttributeUsage(System.AttributeTargets.Class, AllowMultiple = false, Inherited = false)]
    public sealed partial class HideModuleNameAttribute : System.Attribute
    {
    }

    [CompilerServices.StandardModule]
    public sealed partial class Strings
    {
        internal Strings() { }

        public static int AscW(char String) { throw null; }

        public static int AscW(string String) { throw null; }

        public static char ChrW(int CharCode) { throw null; }
    }
}

namespace Microsoft.VisualBasic.CompilerServices
{
    public sealed partial class Conversions
    {
        internal Conversions() { }

        public static object ChangeType(object Expression, System.Type TargetType) { throw null; }

        public static bool ToBoolean(object Value) { throw null; }

        public static bool ToBoolean(string Value) { throw null; }

        public static byte ToByte(object Value) { throw null; }

        public static byte ToByte(string Value) { throw null; }

        public static char ToChar(object Value) { throw null; }

        public static char ToChar(string Value) { throw null; }

        public static char[] ToCharArrayRankOne(object Value) { throw null; }

        public static char[] ToCharArrayRankOne(string Value) { throw null; }

        public static System.DateTime ToDate(object Value) { throw null; }

        public static System.DateTime ToDate(string Value) { throw null; }

        public static decimal ToDecimal(bool Value) { throw null; }

        public static decimal ToDecimal(object Value) { throw null; }

        public static decimal ToDecimal(string Value) { throw null; }

        public static double ToDouble(object Value) { throw null; }

        public static double ToDouble(string Value) { throw null; }

        public static T ToGenericParameter<T>(object Value) { throw null; }

        public static int ToInteger(object Value) { throw null; }

        public static int ToInteger(string Value) { throw null; }

        public static long ToLong(object Value) { throw null; }

        public static long ToLong(string Value) { throw null; }

        [System.CLSCompliant(false)]
        public static sbyte ToSByte(object Value) { throw null; }

        [System.CLSCompliant(false)]
        public static sbyte ToSByte(string Value) { throw null; }

        public static short ToShort(object Value) { throw null; }

        public static short ToShort(string Value) { throw null; }

        public static float ToSingle(object Value) { throw null; }

        public static float ToSingle(string Value) { throw null; }

        public static string ToString(bool Value) { throw null; }

        public static string ToString(byte Value) { throw null; }

        public static string ToString(char Value) { throw null; }

        public static string ToString(System.DateTime Value) { throw null; }

        public static string ToString(decimal Value) { throw null; }

        public static string ToString(double Value) { throw null; }

        public static string ToString(short Value) { throw null; }

        public static string ToString(int Value) { throw null; }

        public static string ToString(long Value) { throw null; }

        public static string ToString(object Value) { throw null; }

        public static string ToString(float Value) { throw null; }

        [System.CLSCompliant(false)]
        public static string ToString(uint Value) { throw null; }

        [System.CLSCompliant(false)]
        public static string ToString(ulong Value) { throw null; }

        [System.CLSCompliant(false)]
        public static uint ToUInteger(object Value) { throw null; }

        [System.CLSCompliant(false)]
        public static uint ToUInteger(string Value) { throw null; }

        [System.CLSCompliant(false)]
        public static ulong ToULong(object Value) { throw null; }

        [System.CLSCompliant(false)]
        public static ulong ToULong(string Value) { throw null; }

        [System.CLSCompliant(false)]
        public static ushort ToUShort(object Value) { throw null; }

        [System.CLSCompliant(false)]
        public static ushort ToUShort(string Value) { throw null; }
    }

    [System.AttributeUsage(System.AttributeTargets.Class, AllowMultiple = false, Inherited = false)]
    public sealed partial class DesignerGeneratedAttribute : System.Attribute
    {
    }

    public sealed partial class IncompleteInitialization : System.Exception
    {
    }

    public sealed partial class NewLateBinding
    {
        internal NewLateBinding() { }

        public static object LateCall(object Instance, System.Type Type, string MemberName, object[] Arguments, string[] ArgumentNames, System.Type[] TypeArguments, bool[] CopyBack, bool IgnoreReturn) { throw null; }

        public static object LateGet(object Instance, System.Type Type, string MemberName, object[] Arguments, string[] ArgumentNames, System.Type[] TypeArguments, bool[] CopyBack) { throw null; }

        public static object LateIndexGet(object Instance, object[] Arguments, string[] ArgumentNames) { throw null; }

        public static void LateIndexSet(object Instance, object[] Arguments, string[] ArgumentNames) { }

        public static void LateIndexSetComplex(object Instance, object[] Arguments, string[] ArgumentNames, bool OptimisticSet, bool RValueBase) { }

        public static void LateSet(object Instance, System.Type Type, string MemberName, object[] Arguments, string[] ArgumentNames, System.Type[] TypeArguments, bool OptimisticSet, bool RValueBase, CallType CallType) { }

        public static void LateSet(object Instance, System.Type Type, string MemberName, object[] Arguments, string[] ArgumentNames, System.Type[] TypeArguments) { }

        public static void LateSetComplex(object Instance, System.Type Type, string MemberName, object[] Arguments, string[] ArgumentNames, System.Type[] TypeArguments, bool OptimisticSet, bool RValueBase) { }
    }

    public sealed partial class ObjectFlowControl
    {
        internal ObjectFlowControl() { }

        public static void CheckForSyncLockOnValueType(object Expression) { }

        public sealed partial class ForLoopControl
        {
            internal ForLoopControl() { }

            public static bool ForLoopInitObj(object Counter, object Start, object Limit, object StepValue, ref object LoopForResult, ref object CounterResult) { throw null; }

            public static bool ForNextCheckDec(decimal count, decimal limit, decimal StepValue) { throw null; }

            public static bool ForNextCheckObj(object Counter, object LoopObj, ref object CounterResult) { throw null; }

            public static bool ForNextCheckR4(float count, float limit, float StepValue) { throw null; }

            public static bool ForNextCheckR8(double count, double limit, double StepValue) { throw null; }
        }
    }

    public sealed partial class Operators
    {
        internal Operators() { }

        public static object AddObject(object Left, object Right) { throw null; }

        public static object AndObject(object Left, object Right) { throw null; }

        public static object CompareObjectEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static object CompareObjectGreater(object Left, object Right, bool TextCompare) { throw null; }

        public static object CompareObjectGreaterEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static object CompareObjectLess(object Left, object Right, bool TextCompare) { throw null; }

        public static object CompareObjectLessEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static object CompareObjectNotEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static int CompareString(string Left, string Right, bool TextCompare) { throw null; }

        public static object ConcatenateObject(object Left, object Right) { throw null; }

        public static bool ConditionalCompareObjectEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static bool ConditionalCompareObjectGreater(object Left, object Right, bool TextCompare) { throw null; }

        public static bool ConditionalCompareObjectGreaterEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static bool ConditionalCompareObjectLess(object Left, object Right, bool TextCompare) { throw null; }

        public static bool ConditionalCompareObjectLessEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static bool ConditionalCompareObjectNotEqual(object Left, object Right, bool TextCompare) { throw null; }

        public static object DivideObject(object Left, object Right) { throw null; }

        public static object ExponentObject(object Left, object Right) { throw null; }

        public static object IntDivideObject(object Left, object Right) { throw null; }

        public static object LeftShiftObject(object Operand, object Amount) { throw null; }

        public static object ModObject(object Left, object Right) { throw null; }

        public static object MultiplyObject(object Left, object Right) { throw null; }

        public static object NegateObject(object Operand) { throw null; }

        public static object NotObject(object Operand) { throw null; }

        public static object OrObject(object Left, object Right) { throw null; }

        public static object PlusObject(object Operand) { throw null; }

        public static object RightShiftObject(object Operand, object Amount) { throw null; }

        public static object SubtractObject(object Left, object Right) { throw null; }

        public static object XorObject(object Left, object Right) { throw null; }
    }

    [System.AttributeUsage(System.AttributeTargets.Parameter, Inherited = false, AllowMultiple = false)]
    public sealed partial class OptionCompareAttribute : System.Attribute
    {
    }

    [System.AttributeUsage(System.AttributeTargets.Class, Inherited = false, AllowMultiple = false)]
    public sealed partial class OptionTextAttribute : System.Attribute
    {
    }

    public sealed partial class ProjectData
    {
        internal ProjectData() { }

        public static void ClearProjectError() { }

        public static void SetProjectError(System.Exception ex, int lErl) { }

        public static void SetProjectError(System.Exception ex) { }
    }

    [System.AttributeUsage(System.AttributeTargets.Class, Inherited = false, AllowMultiple = false)]
    public sealed partial class StandardModuleAttribute : System.Attribute
    {
    }

    public sealed partial class StaticLocalInitFlag
    {
        public short State;
    }

    public sealed partial class Utils
    {
        internal Utils() { }

        public static System.Array CopyArray(System.Array arySrc, System.Array aryDest) { throw null; }
    }
}
